@@ -27,6 +27,7 @@
 
 
 #include <cstdlib>
+#include <cstddef>
 #if defined(sun) && defined(unix)
 #include <malloc.h>
 #endif
@@ -92,12 +93,29 @@
 #define _GNU_SOURCE
 #endif
 
-#if __GNUC__ > 3 || (__GNUC__ == 3 && (__GNU_MINOR__ > 3))
+#if !defined(__GNUC_PREREQ__)
+#if defined(__GNUC__) && defined(__GNUC_MINOR__)
+#define __GNUC_PREREQ__(maj, min) ((__GNUC__ << 16) + __GNUC_MINOR__ >= ((maj) << 16) + (min))
+#else
+#define __GNUC_PREREQ__(maj, min) 0
+#endif
+#endif
+
+#if __GNUC_PREREQ__(3,3)
 #define __PRINTF(x,y)   __attribute__ ((format (printf, x, y)))
 #define __SCANF(x, y) __attribute__ ((format (scanf, x, y)))
 #define __MALLOC      __attribute__ ((malloc))
 #endif
 
+#if __cplusplus <= 199711L && !defined(_MSC_VER)
+#if defined(__GNUC_MINOR__)
+#define nullptr __null
+#else
+#define nullptr NULL
+#warning "Obsolete C++ compiler used, no nullptr support."
+#endif
+#endif
+
 #ifndef __MALLOC
 #define __PRINTF(x, y)
 #define __SCANF(x, y)
@@ -123,23 +141,15 @@
 
 #if defined(_MSC_VER)
 #define NOMINMAX
+#if _MSC_VER < 1500
+#warning "Probably won't build, need VS >= 2010 or later"
+#endif
 #endif
 
-#if defined(_M_X64) || defined(_M_ARM)
-#define _MSCONDITIONALS_
+// minimum required version requires conditional
 #ifndef _WIN32_WINNT
 #define _WIN32_WINNT    0x0600
 #endif
-#endif
-
-//#if defined(_WIN32_WINNT) && _WIN32_WINNT < 0x0501
-//#undef    _WIN32_WINNT
-//#define   _WIN32_WINNT 0x0501
-//#endif
-
-//#ifndef _WIN32_WINNT
-//#define   _WIN32_WINNT 0x0501
-//#endif
 
 #ifdef  _MSC_VER
 #pragma warning(disable: 4251)
@@ -216,9 +226,9 @@ typedef size_t socksize_t;
 #include <io.h>
 
 // gcc c++11 support on mingw requires pthread support library
-#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 7)) && !defined(UCOMMON_SYSRUNTIME) && defined(__MINGW_WINPTHREAD__)
+#if __GNUC_PREREQ__(4, 8) && !defined(UCOMMON_SYSRUNTIME)
+#define __MINGW_WINPTHREAD__
 #include <pthread.h>   // gnu libstdc++ now requires a win pthread
-#undef  _MSCONDITIONALS_
 typedef size_t stacksize_t;
 #else   
 #define _MSTHREADS_
