@@ -103,5 +103,37 @@ extern "C" int main()
     assert(sref.size() == 14);
     assert(sref.copies() == 2);
 
+    arrayref<int> ints(32, 99);
+    ints(4, 27);
+    ints(6, 30);
+    assert(ints.size() == 32);
+    assert(ints[4] == 27);
+    typeref<int> member = ints.at(6);
+    assert(member.copies() == 2);
+    ints.put(member, 6);
+    assert(member.copies() == 2);
+    ints.put(member, 30);
+    assert(*member == 99);
+    assert(member.copies() == 31);
+
+    int memval = member;
+    member = 95;
+    assert(memval == 99);
+    assert(*member == 95);
+    assert(member.copies() == 1);
+    ints(17, memval);
+    ints(18, member);
+    assert(*ints[18] == 95);
+
+    temporary<int> itemp;
+    itemp = 37;
+    itemp[0] = 39;
+    assert(*itemp == 39);
+
+    temporary<int> atemp(7, 2);
+    assert(atemp[3] == 2);
+    atemp[5] = 9;
+    assert(atemp[5] == 9);
+
     return 0;
 }
